@@ -1,7 +1,7 @@
 from django.conf import settings
 
 __author__ = 'phpdude'
-__version__ = (0, 3, 0)
+__version__ = (0, 3, 1)
 
 def correct_path(template_name, prefix):
     if template_name.startswith('/'):
@@ -31,7 +31,7 @@ def process_response(response, tplname):
 
 
 def render_template(template_name, context_processors=None, context_instance=None, mimetype=None):
-    if getattr(settings, 'RENDER_ENGINE', 'django').tolower() == 'coffin':
+    if getattr(settings, 'RENDER_ENGINE', 'django').lower() == 'coffin':
         from coffin.shortcuts import render_to_response
     else:
         from django.shortcuts import render_to_response
